This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

Spelling patch


I've applied the following patch for yet more spelling errors in the gcc
directory.

Index: ChangeLog
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ChangeLog,v
retrieving revision 1.12008
diff -u -r1.12008 ChangeLog
--- ChangeLog	2001/11/23 01:37:01	1.12008
+++ ChangeLog	2001/11/23 01:57:49
@@ -1,5 +1,12 @@
 2001-11-23  Joseph S. Myers  <jsm28@cam.ac.uk>
 
+	* ChangeLog.0, ChangeLog.2, ChangeLog.3, ChangeLog.4, ChangeLog,
+	FSFChangeLog.10, c-decl.c, cppfiles.c, cppinit.c, cpplex.c,
+	cpplib.c, cppmain.c, cse.c, df.c, diagnostic.c, dominance.c,
+	dwarf2out.c, dwarfout.c, emit-rtl.c, errors.c, except.c, except.h,
+	explow.c, function.c, gcse.c, genrecog.c, predict.c, regmove.c,
+	sched-rgn.c, ssa-ccp.c, stmt.c, toplev.c: Fix spelling errors.
+
 	* predict.c, reg-stack.c: Fix spelling errors.
 
 2001-10-09  Andrew Haley  <aph@redhat.com>
@@ -1108,7 +1115,7 @@
 	* output.h (alter_subreg): Update prototype.
 	* sdbout.c (sdbout_symbol): Update call of alter_subreg.
 	* simplify-rtx.c (simplify_subreg): Copy ORIGINAL_REGNO.
-	* Makefile.in (final.o): Add depdendancy on expr.h
+	* Makefile.in (final.o): Add dependency on expr.h
 
 Wed Nov 14 06:37:54 2001  Richard Kenner  <kenner@vlsi1.ultra.nyu.edu>
 
@@ -1591,7 +1598,7 @@
 	* config/ia64/hpux.h (TARGET_VERSION): Likewise.
 	* config/ia64/linux.h (TARGET_VERSION): Likewise.
 	(FUNCTION_PROFILER): Remove.
-	* config/ia64/ia64.h (FUNCTION_PROFILER): Update defintion using the
+	* config/ia64/ia64.h (FUNCTION_PROFILER): Update definition using the
 	version in config/ia64/linux.h.
 	* config/ia64/freebsd.h: New file.
 	* config/freebsd.h: Tidy up.
@@ -2347,7 +2354,7 @@
 
 Mon Nov  5 16:15:25 CET 2001  Jan Hubicka  <jh@suse.cz>
 
-	* Makefile.in (bb-reoder.o): Add dependency on cfglayout.h;
+	* Makefile.in (bb-reorder.o): Add dependency on cfglayout.h;
 	remove unneeded dependencies;
 	(cfglayout.o): New.
 	* cfglayout.c, cfglayout.h: New files; break out from ...
@@ -7398,7 +7405,7 @@
 	* cppinit.c (cpp_create_reader): Set up the token runs.
 	* cpplex.c (lex_directive, lex_token, next_tokenrun): New.
 	(lex_token): New internalised version of _cpp_lex_token.  Don't
-	handle directives or the multiple include opimisation here any
+	handle directives or the multiple include optimization here any
 	more.  Simply lex a token.
 	* cpplib.c (run_directive): Clear bol.
 	(_cpp_pop_buffer): Set bol.
@@ -7528,7 +7535,7 @@
 	(make_reorder_chain_1): Do not use BB indexes.
 	(label_for_bb): Likewise; set BB for new insn.
 	(emit_jump_to_block_after): Likewise.
-	(fixup_reoder_chain): Sanity check that all basic blocks
+	(fixup_reorder_chain): Sanity check that all basic blocks
 	are chained; verify newly created insn chain; remove
 	undocnitional jump simplifying; Do not use BB indexes;
 	properly initialize count and frequency information;
@@ -9396,7 +9403,7 @@
 	Update all callers.
 
 	* final.c (end_final): Abort profile block generation if we
-	havn't layed it out properly.
+	haven't layed it out properly.
 	* output.h (assemble_eh_integer): Remove stale decl.
 	* varasm.c (assemble_zeros): Tidy; use assemble_integer.
 	(min_align): New.
@@ -9658,7 +9665,7 @@
 	(propagate_freq): Use EDGE_DFS_BACK to detect irreducible regions.
 	(estimate_bb_frequencies): Call mark_dfs_back_edges.
 
-	* i386.c (ix86_agi_depdendant): Lea causes AGI only on the Pentium
+	* i386.c (ix86_agi_dependant): Lea causes AGI only on the Pentium
 	(ix86_adjust_cost): Teach scheduler that latency to load operand can
 	be masked.
 
Index: ChangeLog.0
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ChangeLog.0,v
retrieving revision 1.11
diff -u -r1.11 ChangeLog.0
--- ChangeLog.0	2001/10/28 20:08:49	1.11
+++ ChangeLog.0	2001/11/23 01:57:53
@@ -1185,7 +1185,7 @@
 	* c-common.c (c_get_alias_set): New function.
 	* c-decl.c (init_decl_processing): Set lang_get_alias_set.
 
-	* expr.c (protect_from_queue): Propogage alias sets.
+	* expr.c (protect_from_queue): Propagate alias sets.
 	(expand_assignment): Calculate alias set for new MEMs.
 	(expand_expr): Likewise.
 	* function.c (put_var_into_stack): Likewise.
Index: ChangeLog.2
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ChangeLog.2,v
retrieving revision 1.9
diff -u -r1.9 ChangeLog.2
--- ChangeLog.2	2001/11/11 11:25:10	1.9
+++ ChangeLog.2	2001/11/23 01:58:00
@@ -821,7 +821,7 @@
 	* regclass.c  (record_reg_classes): Do not do the copying preferrencing
 	when source does not die.
 
-	* regclass.c (record_reg_classes): Handle INOUT operands propertly.
+	* regclass.c (record_reg_classes): Handle INOUT operands properly.
 
 1999-12-14  Jakub Jelinek  <jakub@redhat.com>
 
@@ -3199,9 +3199,9 @@
 	* rtl.h (renumber_insns): New function.
 	(remove_unnecessary_notes): Likewise.
 	* emit-rtl.c (renumber_insns): Define.
-	(remove_unncessary_notes): Likewise.
+	(remove_unnecessary_notes): Likewise.
 	* toplev.c (rest_of_compilation): Remove dead code.
-	Use renumber_insns and remove_unncessary_notes.
+	Use renumber_insns and remove_unnecessary_notes.
 
 	* gcse.c (struct null_pointer_info): New type.
 	(get_bitmap_width): New function.
@@ -5729,7 +5729,7 @@
 	(life_analysis): Give life_analysis_1 PROP flags.
 	(verify_wide_reg_1, verify_wide_reg): New.
 	(verify_local_live_at_start): New.
-	(update_life_info): Rewrite to call into propogate_block.
+	(update_life_info): Rewrite to call into propagate_block.
 	(mark_reg): New.
 	(mark_regs_live_at_end): After reload, if epilogue as rtl,
 	always mark stack pointer.  Conditionally mark PIC register.
@@ -10985,7 +10985,7 @@
 
 Tue Aug 10 10:47:42 EDT 1999  Andrew MacLeod  <amacleod@cygnus.com>
 
-	* except.h (eh_nesting_info): Add new structure defintion.
+	* except.h (eh_nesting_info): Add new structure definition.
 	(init_eh_nesting_info, free_eh_nesting_info): Add function prototypes.
 	(reachable_handlers, update_rethrow_references): Add function
 	prototypes.
@@ -14401,7 +14401,7 @@
 
 Thu May 20 09:58:57 1999  Jan Hubicka <hubicka@freesoft.cz>
 
-	* function.c (assign_stack_local): Align stack slot propertly.
+	* function.c (assign_stack_local): Align stack slot properly.
 	(assign_outer_stack_local): Likewise.
 
 Thu May 20 10:38:43 1999  Mark Mitchell  <mark@codesourcery.com>
Index: ChangeLog.3
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ChangeLog.3,v
retrieving revision 1.8
diff -u -r1.8 ChangeLog.3
--- ChangeLog.3	2001/11/11 11:25:11	1.8
+++ ChangeLog.3	2001/11/23 01:58:06
@@ -220,8 +220,8 @@
 	(attribute pent_pair): Compute using pent_prefix.
 	(all insn patterns): Set mode,modrm and immediate_length attributes where
 	needed.
-	(cmpsi patterns): Compute sizes propertly for test instruction.
-	(movsi, movhi patterns): Compute sizes propertly for eax shortcuts.
+	(cmpsi patterns): Compute sizes properly for test instruction.
+	(movsi, movhi patterns): Compute sizes properly for eax shortcuts.
 	(movstricthi_xor, movstrictqi_xor): New patterns.
 	(andsi/andhi): Use splitters to generate xor instructions.
 	(xorqi_ext_1): New pattern.
@@ -5186,7 +5186,7 @@
 
 Sat Apr 29 01:15:27 MET DST 2000  Jan Hubicka  <jh@suse.cz>
 
-	* calls.c (calls_function_1):  Propertly handle TREE_LIST expressions;
+	* calls.c (calls_function_1):  Properly handle TREE_LIST expressions;
 	use special_function_p to detect alloca.
 
 Fri Apr 28 16:30:33 2000  Marc Espie <espie@cvs.openbsd.org>
@@ -6789,7 +6789,7 @@
 	!HAVE_cmpstrsi, do libcall when gen_strcmpsi fails.
 
 	* calls.c (expand_call): Do NO_DEFER_POP unconditionally once
-	stack is propertly aligned; add sanity checking for aligned
+	stack is properly aligned; add sanity checking for aligned
 	stack pointer.
 	(expand_library_call_value_1): Add sanity checking for aligned
 	stack pointer.
@@ -8325,7 +8325,7 @@
 	* toplev.c (rtl_dump, jump_opt_dump, etc): Remove.
 	(struct dump_file_info, enum dump_file_index, dump_file): New.
 	(open_dump_file): Take a dump_file_index not a suffix, and a decl
-	not a string.  Clean out file if we havn't yet done so.  Do nothing
+	not a string.  Clean out file if we haven't yet done so.  Do nothing
 	if the dump isn't enabled.
 	(close_dump_file): Do nothing if the dump isn't open.  Dump
 	graph data if requested.
@@ -9649,7 +9649,7 @@
 
 2000-03-18  Mark Mitchell  <mark@codesourcery.com>
 
-	* emit-rtl.c (remove_unncessary_notes): Check that all
+	* emit-rtl.c (remove_unnecessary_notes): Check that all
 	NOTE_INSN_BLOCK_BEG and NOTE_INSN_BLOCK_END notes have an
 	associated NOTE_BLOCK.
 	* function.h (identify_blocks): Update comments.
@@ -11942,7 +11942,7 @@
 	* stmt.c (is_body_block): Move...
 	* dwarfout.c, dwarf2out.c: ...from here.
 	* tree.h: Declare it.
-	* emit-rtl.c (remove_unncessary_notes): Don't remove the body block.
+	* emit-rtl.c (remove_unnecessary_notes): Don't remove the body block.
 	* final.c (final_start_function): Do call remove_unnecessary_notes
 	when scheduling.
 
@@ -11990,7 +11990,7 @@
 	remove_unnecessary_notes.
 	(debug_ignore_block): New fn.
 	* toplev.h: Declare it.
-	* emit-rtl.c (remove_unncessary_notes): Call it.
+	* emit-rtl.c (remove_unnecessary_notes): Call it.
 	* dwarf2out.c (dwarf2out_ignore_block): New fn.
 	* dwarf2out.h: Declare it.
 	* final.c (final_start_function): Don't call remove_unnecessary_notes
@@ -12408,7 +12408,7 @@
 
 2000-02-27  Mark Mitchell  <mark@codesourcery.com>
 
-	* emit-rtl.c (remove_unncessary_notes): Remove notes for empty
+	* emit-rtl.c (remove_unnecessary_notes): Remove notes for empty
 	blocks.
 	* final.c (next_block_index): Remove.
 	(max_block_depth): Likewise.
@@ -13327,7 +13327,7 @@
 
 	* config/arm/arm.c (arm_init_cumulative_args); New function:
 	Initlaise the CUMULATIE_ARGS strcuture for a function
-	defintion.
+	definition.
 	(arm_function_arg): New function: Determine where to place a
 	function's argument.  Also handles deciding the function's
 	call cookie.
Index: ChangeLog.4
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ChangeLog.4,v
retrieving revision 1.9
diff -u -r1.9 ChangeLog.4
--- ChangeLog.4	2001/11/11 11:25:12	1.9
+++ ChangeLog.4	2001/11/23 01:58:16
@@ -4104,7 +4104,7 @@
 	(cpp_get_token): Handle empty macro expansions.  Don't worry
 	about CPP_PLACEMARKERs.
 	(_cpp_create_definition): Empty macros are now empty.
-	(cpp_macro_defintion): Don't special case empty macros.
+	(cpp_macro_definition): Don't special case empty macros.
 	* scan-decls.c: Don't bother with CPP_PLACEMARKERs.
 	* c-lex.c: Similarly.
 
@@ -10131,7 +10131,7 @@
 	(adjust_insn_length): Use output_movsisf, output_movqi,
 	output_movhi for insn length adjusting.
 	(reg_unused_after): Use dead_or_set_p.
-	(preferred_reload_class): Now havn't any restriction.
+	(preferred_reload_class): Now haven't any restriction.
 	(reg_was_0): New function.
 	(io_address_p): Likewise.
 	(const_int_pow2_p): Likewise.
Index: FSFChangeLog.10
===================================================================
RCS file: /cvs/gcc/gcc/gcc/FSFChangeLog.10,v
retrieving revision 1.7
diff -u -r1.7 FSFChangeLog.10
--- FSFChangeLog.10	2001/11/04 02:51:20	1.7
+++ FSFChangeLog.10	2001/11/23 01:58:19
@@ -4184,7 +4184,7 @@
 	(ASM_SPEC): Pass appropriate -mxxx switches to the assembler based
 	on the -mcpu=xxx options.
 	(ASM_OUTPUT_INT): Move here from eabi.h.
-	(ENCODE_SECTION_INFO): If -mcall-{nt,aixdesc} add approriate magic
+	(ENCODE_SECTION_INFO): If -mcall-{nt,aixdesc} add appropriate magic
 	so function name has two or one leading periods.
 	(ASM_OUTPUT_SOURCE_LINE): Delete, use version in svr4.h.
 	(trampoline macros): Call trampoline functions in rs6000.c.
Index: c-decl.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/c-decl.c,v
retrieving revision 1.270
diff -u -r1.270 c-decl.c
--- c-decl.c	2001/11/21 11:08:59	1.270
+++ c-decl.c	2001/11/23 01:58:21
@@ -6808,7 +6808,7 @@
              function could not be deferred.  */
 	  && defer_fn (fndecl))
 	{
-	  /* Let the back-end know that this funtion exists.  */
+	  /* Let the back-end know that this function exists.  */
 	  (*debug_hooks->deferred_inline_function) (fndecl);
           timevar_pop (TV_INTEGRATION);
 	  return;
Index: cppfiles.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cppfiles.c,v
retrieving revision 1.133
diff -u -r1.133 cppfiles.c
--- cppfiles.c	2001/11/21 22:03:27	1.133
+++ cppfiles.c	2001/11/23 01:58:21
@@ -648,7 +648,7 @@
      we can still produce correct output.  Otherwise, we can't produce
      correct output, because there may be dependencies we need inside
      the missing file, and we don't know what directory this missing
-     file exists in.  FIXME: Use a future cpp_diagnotic_with_errno ()
+     file exists in.  FIXME: Use a future cpp_diagnostic_with_errno ()
      for both of these cases.  */
   else if (CPP_PRINT_DEPS (pfile) && ! print_dep)
     cpp_warning (pfile, "%s: %s", fname, xstrerror (errno));
Index: cppinit.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cppinit.c,v
retrieving revision 1.190
diff -u -r1.190 cppinit.c
--- cppinit.c	2001/11/21 21:55:36	1.190
+++ cppinit.c	2001/11/23 01:58:22
@@ -1112,7 +1112,7 @@
 {
   /* cpplex.c leaves the final buffer on the stack.  This it so that
      it returns an unending stream of CPP_EOFs to the client.  If we
-     popped the buffer, we'd derefence a NULL buffer pointer and
+     popped the buffer, we'd dereference a NULL buffer pointer and
      segfault.  It's nice to allow the client to do worry-free excess
      cpp_get_token calls.  */
   while (pfile->buffer)
Index: cpplex.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cpplex.c,v
retrieving revision 1.180
diff -u -r1.180 cpplex.c
--- cpplex.c	2001/11/10 04:46:01	1.180
+++ cpplex.c	2001/11/23 01:58:22
@@ -292,7 +292,7 @@
 	    break;
 
 	  /* Warn about potential nested comments, but not if the '/'
-	     comes immediately before the true comment delimeter.
+	     comes immediately before the true comment delimiter.
 	     Don't bother to get it right across escaped newlines.  */
 	  if (CPP_OPTION (pfile, warn_comments)
 	      && buffer->cur + 1 < buffer->rlimit
@@ -817,7 +817,7 @@
 
 /* Lex a token into RESULT (external interface).  Takes care of issues
    like directive handling, token lookahead, multiple include
-   opimisation and skipping.  */
+   optimization and skipping.  */
 const cpp_token *
 _cpp_lex_token (pfile)
      cpp_reader *pfile;
Index: cpplib.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cpplib.c,v
retrieving revision 1.285
diff -u -r1.285 cpplib.c
--- cpplib.c	2001/10/21 14:04:42	1.285
+++ cpplib.c	2001/11/23 01:58:22
@@ -352,7 +352,7 @@
 	 does not cause '#define foo bar' to get executed when
 	 compiled with -save-temps, we recognize directives in
 	 -fpreprocessed mode only if the # is in column 1.  cppmacro.c
-	 puts a space in fron of any '#' at the start of a macro.  */
+	 puts a space in front of any '#' at the start of a macro.  */
       if (CPP_OPTION (pfile, preprocessed)
 	  && (indented || !(dir->flags & IN_I)))
 	{
@@ -790,7 +790,7 @@
 
 /* Arrange the file_change callback.  pfile->line has changed to
    FILE_LINE of TO_FILE, for reason REASON.  SYSP is 1 for a system
-   header, 2 for a sytem header that needs to be extern "C" protected,
+   header, 2 for a system header that needs to be extern "C" protected,
    and zero otherwise.  */
 void
 _cpp_do_file_change (pfile, reason, to_file, file_line, sysp)
Index: cppmain.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cppmain.c,v
retrieving revision 1.86
diff -u -r1.86 cppmain.c
--- cppmain.c	2001/11/15 10:00:28	1.86
+++ cppmain.c	2001/11/23 01:58:22
@@ -76,7 +76,7 @@
 {
   general_init (argv[0]);
 
-  /* Contruct a reader with default language GNU C89.  */
+  /* Construct a reader with default language GNU C89.  */
   pfile = cpp_create_reader (CLK_GNUC89);
   options = cpp_get_options (pfile);
   
Index: cse.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cse.c,v
retrieving revision 1.212
diff -u -r1.212 cse.c
--- cse.c	2001/11/07 12:57:17	1.212
+++ cse.c	2001/11/23 01:58:24
@@ -728,7 +728,7 @@
 
 /* Return an estimate of the cost of the registers used in an rtx.
    This is mostly the number of different REG expressions in the rtx;
-   however for some excecptions like fixed registers we use a cost of
+   however for some exceptions like fixed registers we use a cost of
    0.  If any other hard register reference occurs, return MAX_COST.  */
 
 static int
@@ -905,7 +905,7 @@
 }
 
 /* Return cost of address expression X.
-   Expect that X is propertly formed address reference.  */
+   Expect that X is properly formed address reference.  */
 
 int
 address_cost (x, mode)
@@ -4132,7 +4132,7 @@
 	     CONST_INT, see if we can find a register equivalent to the
 	     positive constant.  Make a MINUS if so.  Don't do this for
 	     a non-negative constant since we might then alternate between
-	     chosing positive and negative constants.  Having the positive
+	     choosing positive and negative constants.  Having the positive
 	     constant previously-used is the more common case.  Be sure
 	     the resulting constant is non-negative; if const_arg1 were
 	     the smallest negative number this would overflow: depending
Index: diagnostic.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/diagnostic.c,v
retrieving revision 1.70
diff -u -r1.70 diagnostic.c
--- diagnostic.c	2001/09/13 14:37:10	1.70
+++ diagnostic.c	2001/11/23 01:58:24
@@ -175,7 +175,7 @@
   diagnostic_finalizer (context) = default_diagnostic_finalizer;
 }
 
-/* Returns true if BUFFER is in line-wrappind mode.  */
+/* Returns true if BUFFER is in line-wrapping mode.  */
 
 int
 output_is_line_wrapping (buffer)
@@ -202,7 +202,7 @@
 {
   /* If we're told not to wrap lines then do the obvious thing.  In case
    we'll emit prefix only once per diagnostic message, it is appropriate
-  not to increase unncessarily the line-length cut-off.  */
+  not to increase unnecessarily the line-length cut-off.  */
   if (! output_is_line_wrapping (buffer)
       || diagnostic_prefixing_rule (buffer) == DIAGNOSTICS_SHOW_PREFIX_ONCE
       || diagnostic_prefixing_rule (buffer) == DIAGNOSTICS_SHOW_PREFIX_NEVER)
@@ -547,7 +547,7 @@
   
   while (start != end)
     {
-      /* Dump anything bodered by whitespaces.  */ 
+      /* Dump anything bordered by whitespaces.  */ 
       {
         const char *p = start;
         while (p != end && *p != ' ' && *p != '\n')
@@ -752,7 +752,7 @@
 }
 
 /*  Return a malloc'd string containing MSG formatted a la
-    printf.  The caller is reponsible for freeing the memory.  */
+    printf.  The caller is responsible for freeing the memory.  */
 
 static char *
 build_message_string VPARAMS ((const char *msg, ...))
@@ -1296,7 +1296,7 @@
   fflush (output_buffer_attached_stream (buffer));
 }
 
-/* Helper subroutine of output_verbatim and verbatim. Do the approriate
+/* Helper subroutine of output_verbatim and verbatim. Do the appropriate
    settings needed by BUFFER for a verbatim formatting.  */
 
 static void
Index: dominance.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/dominance.c,v
retrieving revision 1.4
diff -u -r1.4 dominance.c
--- dominance.c	2001/08/22 14:35:01	1.4
+++ dominance.c	2001/11/23 01:58:25
@@ -28,7 +28,7 @@
    block I(X), called the immediate dominator of X, which is the parent of X
    in the dominator tree.
 
-   The algorithm computes this dominator tree implicitely by computing for
+   The algorithm computes this dominator tree implicitly by computing for
    each block its immediate dominator.  We use tree balancing and path
    compression, so its the O(e*a(e,v)) variant, where a(e,v) is the very
    slowly growing functional inverse of the Ackerman function.  */
@@ -89,7 +89,7 @@
      number of that node in DFS order counted from 1.  This is an index
      into most of the other arrays in this structure.  */
   TBB *dfs_order;
-  /* If x is the DFS-index of a node which correspondends with an basic block,
+  /* If x is the DFS-index of a node which corresponds with an basic block,
      dfs_to_bb[x] is that basic block.  Note, that in our structure there are
      more nodes that basic blocks, so only dfs_to_bb[dfs_order[bb->index]]==bb
      is true for every basic block bb, but not the opposite.  */
@@ -523,7 +523,7 @@
       v--;
     }
 
-  /* Explicitely define the dominators.  */
+  /* Explicitly define the dominators.  */
   di->dom[1] = 0;
   for (v = 2; v <= di->nodes; v++)
     if (di->dom[v] != di->key[v])
Index: dwarf2out.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/dwarf2out.c,v
retrieving revision 1.331
diff -u -r1.331 dwarf2out.c
--- dwarf2out.c	2001/11/19 20:38:07	1.331
+++ dwarf2out.c	2001/11/23 01:58:27
@@ -3004,7 +3004,7 @@
 	  cfa->offset = ptr->dw_loc_oprnd1.v.val_unsigned;
 	  break;
 	default:
-	  internal_error ("DW_LOC_OP %s not implememnted\n",
+	  internal_error ("DW_LOC_OP %s not implemented\n",
 			  dwarf_stack_op_name (ptr->dw_loc_opc));
 	}
     }
@@ -3224,7 +3224,7 @@
    This value was chosen to give a reasonable range of values.  */
 #define DWARF_LINE_BASE  -10
 
-/* First special line opcde - leave room for the standard opcodes.  */
+/* First special line opcode - leave room for the standard opcodes.  */
 #define DWARF_LINE_OPCODE_BASE  10
 
 /* Range of line offsets in a special line info. opcode.  */
@@ -4752,7 +4752,7 @@
 
 /* Return the "low pc" attribute value, typically associated with
    a subprogram DIE.  Return null if the "low pc" attribute is
-   either not prsent, or if it cannot be represented as an
+   either not present, or if it cannot be represented as an
    assembler label identifier.  */
 
 static inline const char *
@@ -4765,7 +4765,7 @@
 
 /* Return the "high pc" attribute value, typically associated with
    a subprogram DIE.  Return null if the "high pc" attribute is
-   either not prsent, or if it cannot be represented as an
+   either not present, or if it cannot be represented as an
    assembler label identifier.  */
 
 static inline const char *
Index: emit-rtl.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/emit-rtl.c,v
retrieving revision 1.228
diff -u -r1.228 emit-rtl.c
--- emit-rtl.c	2001/11/20 11:50:23	1.228
+++ emit-rtl.c	2001/11/23 01:58:29
@@ -1336,7 +1336,7 @@
 	 ??? This is a potential portability problem and should
 	 be fixed at some point.
 
-	 We must excercise caution with the sign bit.  By definition there
+	 We must exercise caution with the sign bit.  By definition there
 	 are 32 significant bits in K; there may be more in a HOST_WIDE_INT.
 	 Consider a host with a 32-bit long and a 64-bit HOST_WIDE_INT.
 	 So we explicitly mask and sign-extend as necessary.  */
@@ -2837,7 +2837,7 @@
 		    && !find_reg_note (insn, REG_BR_PROB, 0))
 		  {
 		    /* We can preserve the REG_BR_PROB notes only if exactly
-		       one jump is created, otherwise the machinde description
+		       one jump is created, otherwise the machine description
 		       is responsible for this step using
 		       split_branch_probability variable.  */
 		    if (njumps != 1)
@@ -3087,7 +3087,7 @@
     {
       set_block_for_insn (insn, bb);
       /* Should not happen as first in the BB is always
-	 eigther NOTE or LABEL.  */
+	 either NOTE or LABEL.  */
       if (bb->end == after
 	  /* Avoid clobbering of structure when creating new BB.  */
 	  && GET_CODE (insn) != BARRIER
@@ -3154,7 +3154,7 @@
     {
       set_block_for_insn (insn, bb);
       /* Should not happen as first in the BB is always
-	 eigther NOTE or LABEl.  */
+	 either NOTE or LABEl.  */
       if (bb->head == insn
 	  /* Avoid clobbering of structure when creating new BB.  */
 	  && GET_CODE (insn) != BARRIER
@@ -4668,7 +4668,7 @@
 #ifdef INIT_EXPANDERS
   /* This is to initialize {init|mark|free}_machine_status before the first
      call to push_function_context_to.  This is needed by the Chill front
-     end which calls push_function_context_to before the first cal to
+     end which calls push_function_context_to before the first call to
      init_function_start.  */
   INIT_EXPANDERS;
 #endif
Index: errors.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/errors.c,v
retrieving revision 1.8
diff -u -r1.8 errors.c
--- errors.c	2001/08/27 06:48:40	1.8
+++ errors.c	2001/11/23 01:58:29
@@ -100,7 +100,7 @@
    shares no directory elements with the pathname of __FILE__.  This
    is used by fancy_abort() to print `Internal compiler error in expr.c'
    instead of `Internal compiler error in ../../GCC/gcc/expr.c'.  This
-   version if for the gen* programs and so neededn't handle subdirectories.  */
+   version if for the gen* programs and so needn't handle subdirectories.  */
 
 const char *
 trim_filename (name)
Index: except.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/except.c,v
retrieving revision 1.203
diff -u -r1.203 except.c
--- except.c	2001/11/17 17:33:57	1.203
+++ except.c	2001/11/23 01:58:30
@@ -679,7 +679,7 @@
   struct eh_region *cur_region = cfun->eh->cur_region;
   rtx note;
 
-  /* Create a nute marking the end of this region.  */
+  /* Create a note marking the end of this region.  */
   note = emit_note (NULL, NOTE_INSN_EH_REGION_END);
   NOTE_EH_HANDLER (note) = cur_region->region_number;
 
@@ -715,7 +715,7 @@
   emit_label (region->label);
 
   /* Give the language a chance to specify an action to be taken if an
-     exception is thrown that would propogate out of the HANDLER.  */
+     exception is thrown that would propagate out of the HANDLER.  */
   protect_cleanup_actions 
     = (lang_protect_cleanup_actions 
        ? (*lang_protect_cleanup_actions) () 
@@ -1559,7 +1559,7 @@
   slot = (tree *) htab_find_slot_with_hash (type_to_runtime_map, type,
 					    TYPE_HASH (type), NO_INSERT);
 
-  /* We should have always inserrted the data earlier.  */
+  /* We should have always inserted the data earlier.  */
   return TREE_VALUE (*slot);
 }
 
@@ -1784,7 +1784,7 @@
 	       all the way up the chain until blocked by a cleanup.  */
 	  /* ??? Outer try regions can share landing pads with inner
 	     try regions if the types are completely non-overlapping,
-	     and there are no interveaning cleanups.  */
+	     and there are no intervening cleanups.  */
 
 	  region->post_landing_pad = gen_label_rtx ();
 
@@ -3243,7 +3243,7 @@
       /* Process the associated catch regions in reverse order.
 	 If there's a catch-all handler, then we don't need to
 	 search outer regions.  Use a magic -3 value to record
-	 that we havn't done the outer search.  */
+	 that we haven't done the outer search.  */
       next = -3;
       for (c = region->u.try.last_catch; c ; c = c->u.catch.prev_catch)
 	{
Index: except.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/except.h,v
retrieving revision 1.58
diff -u -r1.58 except.h
--- except.h	2001/11/16 12:48:18	1.58
+++ except.h	2001/11/23 01:58:30
@@ -149,7 +149,7 @@
 
 
 /* If non-NULL, this is a function that returns an expression to be
-   executed if an unhandled exception is propogated out of a cleanup
+   executed if an unhandled exception is propagated out of a cleanup
    region.  For example, in C++, an exception thrown by a destructor
    during stack unwinding is required to result in a call to
    `std::terminate', so the C++ version of this function returns a
Index: explow.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/explow.c,v
retrieving revision 1.85
diff -u -r1.85 explow.c
--- explow.c	2001/11/21 11:13:14	1.85
+++ explow.c	2001/11/23 01:58:30
@@ -1287,7 +1287,7 @@
   do_pending_stack_adjust ();
 
  /* We ought to be called always on the toplevel and stack ought to be aligned
-    propertly.  */
+    properly.  */
   if (stack_pointer_delta % (PREFERRED_STACK_BOUNDARY / BITS_PER_UNIT))
     abort ();
 
Index: function.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/function.c,v
retrieving revision 1.326
diff -u -r1.326 function.c
--- function.c	2001/11/21 23:41:39	1.326
+++ function.c	2001/11/23 01:58:31
@@ -6802,7 +6802,7 @@
   emit_line_note_force (filename, line);
 
   /* Before the return label (if any), clobber the return
-     registers so that they are not propogated live to the rest of
+     registers so that they are not propagated live to the rest of
      the function.  This can only happen with functions that drop
      through; if there had been a return statement, there would
      have either been a return rtx, or a jump to the return label.
Index: gcse.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/gcse.c,v
retrieving revision 1.166
diff -u -r1.166 gcse.c
--- gcse.c	2001/11/19 21:51:53	1.166
+++ gcse.c	2001/11/23 01:58:33
@@ -2177,7 +2177,7 @@
 	  /* Don't GCSE if it has attached REG_EQUIV note.
 	     At this point this only function parameters should have
 	     REG_EQUIV notes and if the argument slot is used somewhere
-	     explicitely, it means address of parameter has been taken,
+	     explicitly, it means address of parameter has been taken,
 	     so we should not extend the lifetime of the pseudo.  */
 	  && ((note = find_reg_note (insn, REG_EQUIV, NULL_RTX)) == 0
 	      || GET_CODE (XEXP (note, 0)) != MEM))
Index: genrecog.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/genrecog.c,v
retrieving revision 1.112
diff -u -r1.112 genrecog.c
--- genrecog.c	2001/11/14 20:17:07	1.112
+++ genrecog.c	2001/11/23 01:58:33
@@ -1665,7 +1665,7 @@
 {
   struct decision *p, *q, *afterward;
 
-  /* We can't propogate alternatives across subroutine boundaries.
+  /* We can't propagate alternatives across subroutine boundaries.
      This is not incorrect, merely a minor optimization loss.  */
 
   p = head->first;
Index: predict.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/predict.c,v
retrieving revision 1.47
diff -u -r1.47 predict.c
--- predict.c	2001/11/23 01:37:05	1.47
+++ predict.c	2001/11/23 01:58:33
@@ -556,7 +556,7 @@
 	  continue;
 
 	case JUMP_INSN:
-	  /* Look for simple conditional branches.  If we havn't got an
+	  /* Look for simple conditional branches.  If we haven't got an
 	     expected value yet, no point going further.  */
 	  if (GET_CODE (insn) != JUMP_INSN || ev == NULL_RTX)
 	    continue;
Index: regmove.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/regmove.c,v
retrieving revision 1.119
diff -u -r1.119 regmove.c
--- regmove.c	2001/10/28 20:09:15	1.119
+++ regmove.c	2001/11/23 01:58:34
@@ -2086,7 +2086,7 @@
 }
 
 /* Track stack adjustments and stack memory references.  Attempt to
-   reduce the number of stack adjustments by back-propogating across
+   reduce the number of stack adjustments by back-propagating across
    the memory references.
 
    This is intended primarily for use with targets that do not define
@@ -2096,7 +2096,7 @@
    (e.g. x86 fp regs) which would ordinarily have to be implemented
    as a sub/mov pair due to restrictions in calls.c.
 
-   Propogation stops when any of the insns that need adjusting are
+   Propagation stops when any of the insns that need adjusting are
    (a) no longer valid because we've exceeded their range, (b) a
    non-trivial push instruction, or (c) a call instruction.
 
Index: sched-rgn.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/sched-rgn.c,v
retrieving revision 1.25
diff -u -r1.25 sched-rgn.c
--- sched-rgn.c	2001/11/11 11:25:28	1.25
+++ sched-rgn.c	2001/11/23 01:58:35
@@ -2058,7 +2058,7 @@
 	      {
 		rtx next;
 
-		/* Note that we havn't squirreled away the notes for
+		/* Note that we haven't squirreled away the notes for
 		   blocks other than the current.  So if this is a
 		   speculative insn, NEXT might otherwise be a note.  */
 		next = next_nonnote_insn (insn);
Index: ssa-ccp.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ssa-ccp.c,v
retrieving revision 1.12
diff -u -r1.12 ssa-ccp.c
--- ssa-ccp.c	2001/11/10 15:48:36	1.12
+++ ssa-ccp.c	2001/11/23 01:58:36
@@ -237,7 +237,7 @@
     }
 }
 
-/* Go through the expression, call the approriate evaluation routines
+/* Go through the expression, call the appropriate evaluation routines
    to attempt cprop */
 static void
 visit_expression (insn, block)
Index: stmt.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/stmt.c,v
retrieving revision 1.229
diff -u -r1.229 stmt.c
--- stmt.c	2001/11/21 11:13:14	1.229
+++ stmt.c	2001/11/23 01:58:37
@@ -3037,7 +3037,7 @@
 
   /* If this function was declared to return a value, but we
      didn't, clobber the return registers so that they are not
-     propogated live to the rest of the function.  */
+     propagated live to the rest of the function.  */
   clobber_return_register ();
 
   expand_null_return_1 (last_insn);
Index: toplev.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/toplev.c,v
retrieving revision 1.542
diff -u -r1.542 toplev.c
--- toplev.c	2001/11/20 10:16:09	1.542
+++ toplev.c	2001/11/23 01:58:39
@@ -4588,7 +4588,7 @@
 }
 
 /* Parse command line options and set default flag values, called
-   after language-independent option-independent intialization.  Do
+   after language-independent option-independent initialization.  Do
    minimal options processing.  Outputting diagnostics is OK, but GC
    and identifier hashtables etc. are not initialized yet.  */
 static void
@@ -4988,7 +4988,7 @@
   decl_printable_name = decl_name;
   lang_expand_expr = (lang_expand_expr_t) do_abort;
 
-  /* Set the language-dependent identifer size.  */
+  /* Set the language-dependent identifier size.  */
   tree_code_length[(int) IDENTIFIER_NODE]
     = ((lang_hooks.identifier_size - sizeof (struct tree_common))
        / sizeof (tree));

Index: df.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/df.c,v
retrieving revision 1.18
diff -u -r1.18 df.c
--- df.c	2001/11/19 17:08:47	1.18
+++ df.c	2001/11/23 01:58:24
@@ -954,8 +954,8 @@
 	 || GET_CODE (dst) == SIGN_EXTRACT
 	 || read_modify_subreg_p (dst))
     {
-      /* Strict low part allways contains SUBREG, but we don't want to make
-	 it appear outside, as whole register is allways considered.  */
+      /* Strict low part always contains SUBREG, but we don't want to make
+	 it appear outside, as whole register is always considered.  */
       if (GET_CODE (dst) == STRICT_LOW_PART)
 	{
 	  loc = &XEXP (dst, 0);
@@ -1334,7 +1334,7 @@
   /* Perhaps the defs should be sorted using a depth first search
      of the CFG (or possibly a breadth first search).  We currently
      scan the basic blocks in reverse order so that the first defs
-     apprear at the start of the chain.  */
+     appear at the start of the chain.  */
 
   for (insn = bb->end; insn && insn != PREV_INSN (bb->head);
        insn = PREV_INSN (insn))
@@ -2531,7 +2531,7 @@
   args.replacement = reg;
   args.modified = 0;
 
-  /* Seach and replace all matching mems within insn.  */
+  /* Search and replace all matching mems within insn.  */
   for_each_rtx (&insn, df_rtx_mem_replace, &args);
 
   if (args.modified)
Index: dwarfout.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/dwarfout.c,v
retrieving revision 1.103
diff -u -r1.103 dwarfout.c
--- dwarfout.c	2001/11/11 11:25:17	1.103
+++ dwarfout.c	2001/11/23 01:58:28
@@ -1354,7 +1354,7 @@
    NOT issue a trailing newline. We define ASM_OUTPUT_DWARF_STRING_NEWLINE
    based on whether ASM_OUTPUT_DWARF_STRING is defined or not. If it is
    defined, we call it, then issue the line feed. If not, we supply a
-   default defintion of calling ASM_OUTPUT_ASCII */
+   default definition of calling ASM_OUTPUT_ASCII */
 
 #ifndef ASM_OUTPUT_DWARF_STRING
 #define ASM_OUTPUT_DWARF_STRING_NEWLINE(FILE,P) \
@@ -1912,7 +1912,7 @@
 	    const char *const name =
 	      IDENTIFIER_POINTER (DECL_NAME (TYPE_NAME (type)));
 
 	    /* Note that here we can run afowl of a serious bug in "classic"
 	       svr4 SDB debuggers.  They don't seem to understand the
 	       FT_ext_prec_float type (even though they should).  */
 
@@ -1934,7 +1934,7 @@
 	if (TYPE_PRECISION (type) == FLOAT_TYPE_SIZE)
 	  return FT_float;
 
 	/* Note that here we can run afowl of a serious bug in "classic"
 	   svr4 SDB debuggers.  They don't seem to understand the
 	   FT_ext_prec_float type (even though they should).  */
 
@@ -5613,7 +5613,7 @@
 
     case PARM_DECL:
      /* Force out the type of this formal, if it was not forced out yet.
-	Note that here we can run afowl of a bug in "classic" svr4 SDB.
+	Note that here we can run afoul of a bug in "classic" svr4 SDB.
 	It should be able to grok the presence of type DIEs within a list
 	of TAG_formal_parameter DIEs, but it doesn't.  */
 
@@ -5717,7 +5717,7 @@
 	 future (i.e. later on within the current translation unit).
 	 So here we just ignore all file-scope function declarations
 	 which are not also definitions.  If and when the debugger needs
-	 to know something about these functions, it wil have to hunt
+	 to know something about these functions, it will have to hunt
 	 around and find the DWARF information associated with the
 	 *definition* of the function.
 
@@ -1912,7 +1912,7 @@
 	      IDENTIFIER_POINTER (DECL_NAME (TYPE_NAME (type)));
 
-	    /* Note that here we can run afowl of a serious bug in "classic"
+	    /* Note that here we can run afoul of a serious bug in "classic"
 	       svr4 SDB debuggers.  They don't seem to understand the
 	       FT_ext_prec_float type (even though they should).  */
@@ -1934,7 +1934,7 @@
 	  return FT_float;
 
-	/* Note that here we can run afowl of a serious bug in "classic"
+	/* Note that here we can run afoul of a serious bug in "classic"
 	   svr4 SDB debuggers.  They don't seem to understand the
 	   FT_ext_prec_float type (even though they should).  */
-- 
Joseph S. Myers
jsm28@cam.ac.uk


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]